

# Py-YouWol

Py-YouWol is the local equivalent of the online YouWol platform, designed to run on a personal computer.
While the online ecosystem of YouWol is the go-to place for sharing resources, the local installation is preferred for the development of those resources.
In fact, even for daily use of YouWol, the local application provides multiple benefits.

Find out more in the [Py-YouWol guide](https://l.youwol.com/doc/py-youwol).

## Links

[Py-YouWol guide](https://l.youwol.com/doc/py-youwol)

[YouWol platform](https://platform.youwol.com/applications/@youwol/platform/latest)

[YouWol guide](https://l.youwol.com/doc/youwol)

# Installation

> Note: Py-YouWol can be installed from PyPi repository,
> see the [Py-YouWol guide](https://l.youwol.com/doc/py-youwol).


To install from source code, you will need to have Git and Python installed on your machine.
Py-YouWol support the Python versions 3.8 & 3.9.

Once you have those, you can follow these steps:

1. Clone the repository from GitHub: `git clone https://github.com/youwol/py-youwol`
2. Navigate to the project directory: `cd py-youwol`
3. Create a virtual environment (recommended) using python3: `python3 -m venv yw_venv`
4. Activate the virtual environment: `source yw_venv/bin/activate` (on Linux/Mac) or `yw_venv\Scripts\activate` (on Windows)
5. Install the required packages: `pip install -r requirements.txt`
6. Run the application: `python main.py`

